@@ -358,6 +358,13 @@ _on_key_press(GtkWidget *widget, GdkEventKey *event, gpointer user_data)
     gboolean result = FALSE;
 
     switch (event->keyval) {
+        case GDK_BackSpace:
+            /* Close the dialog when backspacing on empty widget */
+            if (widget == GTK_WIDGET(app_search->entry) &&
+                    gtk_entry_get_text_length(GTK_ENTRY(app_search->entry)) == 0) {
+                gtk_dialog_response(GTK_DIALOG(app_search->dialog), GTK_RESPONSE_OK);
+            }
+            break;
         case GDK_Up:
         case GDK_Left:
             if (gtk_tree_selection_get_selected(selection, &model, &iter)) {
